==> countess-0.0.62.tar.gz: countess-0.0.62/countess/plugins/correlation.py <==
from typing import Iterable, Optional

import pandas as pd

from countess import VERSION
from countess.core.logger import Logger
from countess.core.parameters import ChoiceParam, ColumnChoiceParam, ColumnOrNoneChoiceParam
from countess.core.plugins import PandasSimplePlugin


class CorrelationPlugin(PandasSimplePlugin):
    """Correlations"""

    name = "Correlation Tool"
    description = "Measures Pearsons / Kendall / Spearman correlation of columns"
    version = VERSION
    link = "https://countess-project.github.io/CountESS/included-plugins/#correlation-tool"

    parameters = {
        "method": ChoiceParam("Method", choices=["pearson", "kendall", "spearman"]),
        "group": ColumnOrNoneChoiceParam("Group"),
        "column1": ColumnChoiceParam("Column 1"),
        "column2": ColumnChoiceParam("Column 2"),
    }
    columns: list[str] = []
    dataframes: list[pd.DataFrame] = []

    def prepare(self, sources: list[str], row_limit: Optional[int] = None):
        assert isinstance(self.parameters["group"], ColumnOrNoneChoiceParam)
        column1 = self.parameters["column1"].value
        column2 = self.parameters["column2"].value
        self.columns = [column1, column2]
        if self.parameters["group"].is_not_none():
            self.columns.append(self.parameters["group"].value)
        self.dataframes = []

    def process_dataframe(self, dataframe: pd.DataFrame, logger: Logger) -> None:
        self.dataframes.append(dataframe[self.columns])

    def finalize(self, logger: Logger) -> Iterable[pd.DataFrame]:
        assert isinstance(self.parameters["group"], ColumnOrNoneChoiceParam)
        column1 = self.parameters["column1"].value
        column2 = self.parameters["column2"].value
        groupby = None if self.parameters["group"].is_none() else self.parameters["group"].value

        method = self.parameters["method"].value

        dataframe = pd.concat(self.dataframes)
        if groupby:
            ds = dataframe.groupby(groupby)[column1]
            yield ds.corr(dataframe[column2], method=method).to_frame(name="correlation")
        else:
            corr = dataframe[column1].corr(dataframe[column2], method=method)
            yield pd.DataFrame([[corr]], columns=["correlation"])

==> countess-0.0.77.tar.gz: countess-0.0.77/countess/plugins/correlation.py <==
from typing import Iterable, Optional

import pandas as pd

from countess import VERSION
from countess.core.parameters import ChoiceParam, ColumnChoiceParam, ColumnOrNoneChoiceParam
from countess.core.plugins import PandasSimplePlugin


class CorrelationPlugin(PandasSimplePlugin):
    """Correlations"""

    name = "Correlation Tool"
    description = "Measures Pearsons / Kendall / Spearman correlation of columns"
    version = VERSION
    link = "https://countess-project.github.io/CountESS/included-plugins/#correlation-tool"

    method = ChoiceParam("Method", choices=["pearson", "kendall", "spearman"])
    group = ColumnOrNoneChoiceParam("Group")
    column1 = ColumnChoiceParam("Column 1")
    column2 = ColumnChoiceParam("Column 2")

    columns: list[str] = []
    dataframes: list[pd.DataFrame] = []

    def prepare(self, sources: list[str], row_limit: Optional[int] = None):
        column1 = self.column1.value
        column2 = self.column2.value
        self.columns = [column1, column2]
        if self.group.is_not_none():
            self.columns.append(self.group.value)
        self.dataframes = []

    def process_dataframe(self, dataframe: pd.DataFrame) -> None:
        self.dataframes.append(dataframe[self.columns])

    def finalize(self) -> Iterable[pd.DataFrame]:
        column1 = self.column1.value
        column2 = self.column2.value
        groupby = None if self.group.is_none() else self.group.value

        method = self.method.value

        dataframe = pd.concat(self.dataframes)
        if groupby:
            ds = dataframe.groupby(groupby)[column1]
            yield ds.corr(dataframe[column2], method=method).to_frame(name="correlation")
        else:
            corr = dataframe[column1].corr(dataframe[column2], method=method)
            yield pd.DataFrame([[corr]], columns=["correlation"])
